import * as i0 from "@angular/core";
export interface DeviceInfo {
    userAgent: string;
    screen_resolution: string;
    browser: string;
    browserVersion: string;
    browserMajorVersion: number;
    osVersion: number;
    os: string;
    cookies: boolean;
}
export declare class AngularDeviceInformationService {
    private platformId;
    private userAgent;
    private appVersion;
    private appName;
    private deviceInfo;
    private filter;
    constructor(platformId: any);
    /**
     * @desc Sets the initial value of the device when the service is initiated.
     * This value is later accessible for usage
     */
    private setDeviceInfo;
    /**
     * @desc Returns the device information
     * @returns the device information object.
     */
    getDeviceInfo(): DeviceInfo;
    /**
     * @desc Compares the current device info with the mobile devices to check
     * if the current device is a mobile and also check current device is tablet so it will return false.
     * @returns whether the current device is a mobile
     */
    isMobile(userAgent?: string): boolean;
    /**
     * @desc Compares the current device info with the tablet devices to check
     * if the current device is a tablet.
     * @returns whether the current device is a tablet
     */
    isTablet(userAgent?: string): boolean;
    /**
     * @desc Compares the current device info with the desktop devices to check
     * if the current device is a desktop device.
     * @returns whether the current device is a desktop device
     */
    isDesktop(userAgent?: string): boolean;
    getDeviceType: (userAgent?: string) => "Tablet" | "Mobile" | "Desktop";
    static ɵfac: i0.ɵɵFactoryDeclaration<AngularDeviceInformationService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<AngularDeviceInformationService>;
}
export declare const MOBILES_RE: {
    HTC: RegExp;
    NEXUS_PHONE: RegExp;
    DELL: RegExp;
    MOTOROLA: RegExp;
    SAMSUNG: RegExp;
    LG: RegExp;
    SONY: RegExp;
    ASUS: RegExp;
    NOKIA_LUMIA: RegExp;
    MICROMAX: RegExp;
    PALM: RegExp;
    VERTU: RegExp;
    PANTECH: RegExp;
    FLY: RegExp;
    WIKO: RegExp;
    I_MOBILE: RegExp;
    SIMVALLEY: RegExp;
    WOLFGANG: RegExp;
    ALCATEL: RegExp;
    NINTENDO: RegExp;
    AMOI: RegExp;
    INQ: RegExp;
    VITA: RegExp;
    BLACKBERRY: RegExp;
    FIREFOX_OS: RegExp;
    IPHONE: RegExp;
    iPod: RegExp;
    ANDROID: RegExp;
    WINDOWS_PHONE: RegExp;
    GENERIC_PHONE: RegExp;
};
export declare const TABLETS_RE: {
    iPad: RegExp;
    NexusTablet: RegExp;
    GoogleTablet: RegExp;
    SamsungTablet: RegExp;
    Kindle: RegExp;
    SurfaceTablet: RegExp;
    HPTablet: RegExp;
    AsusTablet: RegExp;
    BlackBerryTablet: RegExp;
    HTCtablet: RegExp;
    MotorolaTablet: RegExp;
    NookTablet: RegExp;
    AcerTablet: RegExp;
    ToshibaTablet: RegExp;
    LGTablet: RegExp;
    FujitsuTablet: RegExp;
    PrestigioTablet: RegExp;
    LenovoTablet: RegExp;
    DellTablet: RegExp;
    YarvikTablet: RegExp;
    MedionTablet: RegExp;
    ArnovaTablet: RegExp;
    IntensoTablet: RegExp;
    IRUTablet: RegExp;
    MegafonTablet: RegExp;
    EbodaTablet: RegExp;
    AllViewTablet: RegExp;
    ArchosTablet: RegExp;
    AinolTablet: RegExp;
    NokiaLumiaTablet: RegExp;
    SonyTablet: RegExp;
    PhilipsTablet: RegExp;
    CubeTablet: RegExp;
    CobyTablet: RegExp;
    MIDTablet: RegExp;
    MSITablet: RegExp;
    SMiTTablet: RegExp;
    RockChipTablet: RegExp;
    FlyTablet: RegExp;
    bqTablet: RegExp;
    HuaweiTablet: RegExp;
    NecTablet: RegExp;
    PantechTablet: RegExp;
    BronchoTablet: RegExp;
    VersusTablet: RegExp;
    ZyncTablet: RegExp;
    PositivoTablet: RegExp;
    NabiTablet: RegExp;
    KoboTablet: RegExp;
    DanewTablet: RegExp;
    TexetTablet: RegExp;
    PlaystationTablet: RegExp;
    TrekstorTablet: RegExp;
    PyleAudioTablet: RegExp;
    AdvanTablet: RegExp;
    DanyTechTablet: string;
    GalapadTablet: RegExp;
    MicromaxTablet: RegExp;
    KarbonnTablet: RegExp;
    AllFineTablet: RegExp;
    PROSCANTablet: RegExp;
    YONESTablet: RegExp;
    ChangJiaTablet: RegExp;
    GUTablet: RegExp;
    PointOfViewTablet: RegExp;
    OvermaxTablet: RegExp;
    HCLTablet: RegExp;
    DPSTablet: RegExp;
    VistureTablet: RegExp;
    CrestaTablet: RegExp;
    MediatekTablet: RegExp;
    ConcordeTablet: RegExp;
    GoCleverTablet: RegExp;
    ModecomTablet: RegExp;
    VoninoTablet: RegExp;
    ECSTablet: RegExp;
    StorexTablet: RegExp;
    VodafoneTablet: RegExp;
    EssentielBTablet: RegExp;
    RossMoorTablet: RegExp;
    iMobileTablet: RegExp;
    TolinoTablet: RegExp;
    AudioSonicTablet: RegExp;
    AMPETablet: RegExp;
    SkkTablet: RegExp;
    TecnoTablet: RegExp;
    JXDTablet: RegExp;
    iJoyTablet: RegExp;
    FX2Tablet: RegExp;
    XoroTablet: RegExp;
    ViewsonicTablet: RegExp;
    VerizonTablet: RegExp;
    OdysTablet: RegExp;
    CaptivaTablet: RegExp;
    IconbitTablet: RegExp;
    TeclastTablet: RegExp;
    OndaTablet: RegExp;
    JaytechTablet: RegExp;
    BlaupunktTablet: RegExp;
    DigmaTablet: RegExp;
    EvolioTablet: RegExp;
    LavaTablet: RegExp;
    AocTablet: RegExp;
    MpmanTablet: RegExp;
    CelkonTablet: RegExp;
    WolderTablet: RegExp;
    MediacomTablet: string;
    MiTablet: RegExp;
    NibiruTablet: RegExp;
    NexoTablet: RegExp;
    LeaderTablet: RegExp;
    UbislateTablet: RegExp;
    PocketBookTablet: RegExp;
    KocasoTablet: RegExp;
    HisenseTablet: RegExp;
    Hudl: RegExp;
    TelstraTablet: RegExp;
    Honeywell: RegExp;
    GenericTablet: RegExp;
};
